==> chromium-86.0.4190.0.tar.xz: chromium-86.0.4190.0/services/viz/public/cpp/compositing/render_pass_mojom_traits.cc <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "services/viz/public/cpp/compositing/render_pass_mojom_traits.h"

#include "base/numerics/safe_conversions.h"
#include "services/viz/public/cpp/crash_keys.h"
#include "ui/gfx/mojom/display_color_spaces_mojom_traits.h"

namespace mojo {

// static
bool StructTraits<viz::mojom::RenderPassDataView,
                  std::unique_ptr<viz::RenderPass>>::
    Read(viz::mojom::RenderPassDataView data,
         std::unique_ptr<viz::RenderPass>* out) {
  *out = viz::RenderPass::Create();
  if (!data.ReadOutputRect(&(*out)->output_rect) ||
      !data.ReadDamageRect(&(*out)->damage_rect) ||
      !data.ReadTransformToRootTarget(&(*out)->transform_to_root_target) ||
      !data.ReadFilters(&(*out)->filters) ||
      !data.ReadBackdropFilters(&(*out)->backdrop_filters) ||
      !data.ReadBackdropFilterBounds(&(*out)->backdrop_filter_bounds) ||
      !data.ReadContentColorUsage(&(*out)->content_color_usage) ||
      !data.ReadCopyRequests(&(*out)->copy_requests)) {
    return false;
  }
  (*out)->id = data.id();
  // RenderPass ids are never zero.
  if (!(*out)->id) {
    viz::SetDeserializationCrashKeyString("Invalid render pass ID");
    return false;
  }
  (*out)->has_transparent_background = data.has_transparent_background();
  (*out)->cache_render_pass = data.cache_render_pass();
  (*out)->has_damage_from_contributing_content =
      data.has_damage_from_contributing_content();
  (*out)->generate_mipmap = data.generate_mipmap();

  mojo::ArrayDataView<viz::mojom::DrawQuadDataView> quads;
  data.GetQuadListDataView(&quads);
  viz::SharedQuadState* last_sqs = nullptr;
  for (size_t i = 0; i < quads.size(); ++i) {
    viz::mojom::DrawQuadDataView quad_data_view;
    quads.GetDataView(i, &quad_data_view);
    viz::mojom::DrawQuadStateDataView quad_state_data_view;
    quad_data_view.GetDrawQuadStateDataView(&quad_state_data_view);

    viz::DrawQuad* quad =
        AllocateAndConstruct(quad_state_data_view.tag(), &(*out)->quad_list);
    if (!quad) {
      viz::SetDeserializationCrashKeyString("AllocateAndConstruct quad failed");
      return false;
    }
    if (!quads.Read(i, quad))
      return false;

    // Read the SharedQuadState.
    viz::mojom::SharedQuadStateDataView sqs_data_view;
    quad_data_view.GetSqsDataView(&sqs_data_view);
    // If there is no seralized SharedQuadState then used the last deseriaized
    // one.
    if (!sqs_data_view.is_null()) {
      last_sqs = (*out)->CreateAndAppendSharedQuadState();
      if (!quad_data_view.ReadSqs(last_sqs))
        return false;
    }
    quad->shared_quad_state = last_sqs;
    if (!quad->shared_quad_state) {
      viz::SetDeserializationCrashKeyString("No shared quad state");
      return false;
    }
  }
  return true;
}

}  // namespace mojo

==> chromium-86.0.4240.114.tar.xz: chromium-86.0.4240.114/services/viz/public/cpp/compositing/render_pass_mojom_traits.cc <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "services/viz/public/cpp/compositing/render_pass_mojom_traits.h"

#include "base/numerics/safe_conversions.h"
#include "components/viz/common/quads/render_pass.h"
#include "services/viz/public/cpp/compositing/render_pass_id_mojom_traits.h"
#include "services/viz/public/cpp/crash_keys.h"
#include "ui/gfx/mojom/display_color_spaces_mojom_traits.h"

namespace mojo {

// static
bool StructTraits<viz::mojom::RenderPassDataView,
                  std::unique_ptr<viz::RenderPass>>::
    Read(viz::mojom::RenderPassDataView data,
         std::unique_ptr<viz::RenderPass>* out) {
  *out = viz::RenderPass::Create();
  if (!data.ReadOutputRect(&(*out)->output_rect) ||
      !data.ReadDamageRect(&(*out)->damage_rect) ||
      !data.ReadTransformToRootTarget(&(*out)->transform_to_root_target) ||
      !data.ReadFilters(&(*out)->filters) ||
      !data.ReadBackdropFilters(&(*out)->backdrop_filters) ||
      !data.ReadBackdropFilterBounds(&(*out)->backdrop_filter_bounds) ||
      !data.ReadContentColorUsage(&(*out)->content_color_usage) ||
      !data.ReadCopyRequests(&(*out)->copy_requests) ||
      !data.ReadId(&(*out)->id)) {
    return false;
  }
  // RenderPass ids are never zero.
  if (!(*out)->id) {
    viz::SetDeserializationCrashKeyString("Invalid render pass ID");
    return false;
  }
  (*out)->has_transparent_background = data.has_transparent_background();
  (*out)->cache_render_pass = data.cache_render_pass();
  (*out)->has_damage_from_contributing_content =
      data.has_damage_from_contributing_content();
  (*out)->generate_mipmap = data.generate_mipmap();

  mojo::ArrayDataView<viz::mojom::DrawQuadDataView> quads;
  data.GetQuadListDataView(&quads);
  viz::SharedQuadState* last_sqs = nullptr;
  for (size_t i = 0; i < quads.size(); ++i) {
    viz::mojom::DrawQuadDataView quad_data_view;
    quads.GetDataView(i, &quad_data_view);
    viz::mojom::DrawQuadStateDataView quad_state_data_view;
    quad_data_view.GetDrawQuadStateDataView(&quad_state_data_view);

    viz::DrawQuad* quad =
        AllocateAndConstruct(quad_state_data_view.tag(), &(*out)->quad_list);
    if (!quad) {
      viz::SetDeserializationCrashKeyString("AllocateAndConstruct quad failed");
      return false;
    }
    if (!quads.Read(i, quad))
      return false;

    // Read the SharedQuadState.
    viz::mojom::SharedQuadStateDataView sqs_data_view;
    quad_data_view.GetSqsDataView(&sqs_data_view);
    // If there is no seralized SharedQuadState then used the last deseriaized
    // one.
    if (!sqs_data_view.is_null()) {
      last_sqs = (*out)->CreateAndAppendSharedQuadState();
      if (!quad_data_view.ReadSqs(last_sqs))
        return false;
    }
    quad->shared_quad_state = last_sqs;
    if (!quad->shared_quad_state) {
      viz::SetDeserializationCrashKeyString("No shared quad state");
      return false;
    }
  }
  return true;
}

}  // namespace mojo
